@@ -1,9 +1,11 @@
 package cmd
 
 import (
+	stdctx "context"
 	"errors"
 	"io"
 	"os/exec"
+	"strings"
 	"sync"
 
 	"github.com/caarlos0/log"
@@ -56,7 +58,7 @@ func newHealthcheckCmd() *healthcheckCmd {
 			for _, hc := range healthcheck.Healthcheckers {
 				_ = skip.Maybe(hc, func(ctx *context.Context) error {
 					for _, tool := range hc.Dependencies(ctx) {
-						if err := checkPath(tool); err != nil {
+						if err := checkPath(ctx, tool); err != nil {
 							errs = append(errs, err)
 						}
 					}
@@ -84,15 +86,23 @@ func newHealthcheckCmd() *healthcheckCmd {
 
 var toolsChecked = &sync.Map{}
 
-func checkPath(tool string) error {
+func checkPath(ctx stdctx.Context, tool string) error {
 	if _, ok := toolsChecked.LoadOrStore(tool, true); ok {
 		return nil
 	}
-	if _, err := exec.LookPath(tool); err != nil {
+	args := strings.Fields(tool)
+	if _, err := exec.LookPath(args[0]); err != nil {
 		st := log.Styles[log.ErrorLevel]
 		log.Warnf("%s %s - %s", st.Render("⚠"), codeStyle.Render(tool), st.Render("not present in path"))
 		return err
 	}
+	if len(args) > 1 {
+		if err := exec.CommandContext(ctx, args[0], args[1:]...).Run(); err != nil {
+			st := log.Styles[log.ErrorLevel]
+			log.Warnf("%s %s - %s", st.Render("⚠"), codeStyle.Render(tool), st.Render("command failed"))
+			return err
+		}
+	}
 	st := lipgloss.NewStyle().Foreground(lipgloss.Color("2")).Bold(true)
 	log.Infof("%s %s", st.Render("✓"), codeStyle.Render(tool))
 	return nil
