@@ -1,6 +1,8 @@
 package client
 
-import "github.com/goreleaser/goreleaser/pkg/config"
+import "github.com/goreleaser/goreleaser/v2/pkg/config"
+
+const prFooter = "###### Automated with [GoReleaser](https://goreleaser.com)"
 
 // RepoFromRef converts a config.RepoRef into a Repo.
 func RepoFromRef(ref config.RepoRef) Repo {
