@@ -11,6 +11,7 @@ import (
 	"sync"
 	"time"
 
+	"github.com/avast/retry-go/v4"
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/v2/internal/git"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe"
@@ -86,16 +87,36 @@ func (g *gitClient) CreateFiles(
 			return fmt.Errorf("git: failed to create parent: %w", err)
 		}
 
-		if err := cloneRepoWithRetries(ctx, parent, url, name, env); err != nil {
+		if err := cloneRepo(ctx, parent, url, name, env); err != nil {
 			return err
 		}
 
-		if err := runGitCmds(ctx, cwd, env, [][]string{
+		gitCmds := [][]string{
 			{"config", "--local", "user.name", commitAuthor.Name},
 			{"config", "--local", "user.email", commitAuthor.Email},
-			{"config", "--local", "commit.gpgSign", "false"},
 			{"config", "--local", "init.defaultBranch", cmp.Or(g.branch, "master")},
-		}); err != nil {
+		}
+
+		// append git flags for signing to overall comand if configured
+		if commitAuthor.Signing.Enabled {
+			gitCmds = append(gitCmds, []string{"config", "--local", "commit.gpgSign", "true"})
+
+			if commitAuthor.Signing.Key != "" {
+				gitCmds = append(gitCmds, []string{"config", "--local", "user.signingKey", commitAuthor.Signing.Key})
+			}
+
+			if commitAuthor.Signing.Program != "" {
+				gitCmds = append(gitCmds, []string{"config", "--local", "gpg.program", commitAuthor.Signing.Program})
+			}
+
+			if commitAuthor.Signing.Format != "" && commitAuthor.Signing.Format != "openpgp" {
+				gitCmds = append(gitCmds, []string{"config", "--local", "gpg.format", commitAuthor.Signing.Format})
+			}
+		} else {
+			gitCmds = append(gitCmds, []string{"config", "--local", "commit.gpgSign", "false"})
+		}
+
+		if err := runGitCmds(ctx, cwd, env, gitCmds); err != nil {
 			return fmt.Errorf("git: failed to setup local repository: %w", err)
 		}
 		if g.branch != "" {
@@ -199,29 +220,23 @@ func isPasswordError(err error) bool {
 	return errors.As(err, &kerr)
 }
 
-func cloneRepoWithRetries(ctx *context.Context, parent, url, name string, env []string) error {
-	var try int
-	for try < 10 {
-		try++
-		err := runGitCmds(ctx, parent, env, [][]string{{"clone", url, name}})
-		if err == nil {
-			return nil
-		}
-		if isRetriableCloneError(err) {
-			log.WithField("try", try).
-				WithField("image", name).
-				WithError(err).
-				Warnf("failed to push image, will retry")
-			time.Sleep(time.Duration(try*10) * time.Second)
-			continue
-		}
+func cloneRepo(ctx *context.Context, parent, url, name string, env []string) error {
+	if err := retry.Do(
+		func() error {
+			log.WithField("url", url).Infof("cloning %s", name)
+			return runGitCmds(ctx, parent, env, [][]string{{"clone", url, name}})
+		},
+		retry.RetryIf(func(err error) bool {
+			return strings.Contains(err.Error(), "Connection reset") ||
+				strings.Contains(err.Error(), "Network is unreachable")
+		}),
+		retry.Attempts(10),
+		retry.Delay(time.Second),
+		retry.LastErrorOnly(true),
+	); err != nil {
 		return fmt.Errorf("failed to clone local repository: %w", err)
 	}
-	return fmt.Errorf("failed to push %s after %d tries", name, try)
-}
-
-func isRetriableCloneError(err error) bool {
-	return strings.Contains(err.Error(), "Connection reset")
+	return nil
 }
 
 func runGitCmds(ctx *context.Context, cwd string, env []string, cmds [][]string) error {
