@@ -115,15 +115,15 @@ func (Pipe) Run(ctx *context.Context) error {
 			continue
 		}
 
-		filter := []artifact.Filter{artifact.Or(
-			artifact.ByType(artifact.Binary),
-			artifact.ByType(artifact.UniversalBinary),
-			artifact.ByType(artifact.Header),
-			artifact.ByType(artifact.CArchive),
-			artifact.ByType(artifact.CShared),
-		)}
-		if len(archive.IDs) > 0 {
-			filter = append(filter, artifact.ByIDs(archive.IDs...))
+		filter := []artifact.Filter{
+			artifact.ByTypes(
+				artifact.Binary,
+				artifact.UniversalBinary,
+				artifact.Header,
+				artifact.CArchive,
+				artifact.CShared,
+			),
+			artifact.ByIDs(archive.IDs...),
 		}
 
 		isBinary := slices.Contains(archive.Formats, "binary")
@@ -320,6 +320,15 @@ func skip(ctx *context.Context, archive config.Archive, binaries []*artifact.Art
 
 func packageFormats(archive config.Archive, platform string) []string {
 	for _, override := range archive.FormatOverrides {
+		if override.Goos == "" {
+			log.Warn("override has no goos, ignoring")
+			continue
+		}
+		if len(override.Formats) == 0 {
+			log.WithField("goos", override.Goos).
+				Warn("override has no formats, ignoring")
+			continue
+		}
 		if strings.HasPrefix(platform, override.Goos) {
 			return override.Formats
 		}
