@@ -3,10 +3,8 @@ package krew
 import (
 	"fmt"
 	"os"
-	"os/exec"
 	"path"
 	"path/filepath"
-	"strings"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
@@ -120,7 +118,6 @@ func TestFullManifest(t *testing.T) {
 	require.NoError(t, err)
 
 	golden.RequireEqualYaml(t, []byte(manifest))
-	requireValidManifest(t)
 }
 
 func TestSimple(t *testing.T) {
@@ -129,7 +126,6 @@ func TestSimple(t *testing.T) {
 	manifest, err := doBuildManifest(data)
 	require.NoError(t, err)
 	golden.RequireEqualYaml(t, []byte(manifest))
-	requireValidManifest(t)
 }
 
 func TestFullPipe(t *testing.T) {
@@ -266,7 +262,7 @@ func TestFullPipe(t *testing.T) {
 				Goarch:  "amd64",
 				Goamd64: "v1",
 				Type:    artifact.UploadableArchive,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID:     "bar",
 					artifact.ExtraFormat: "tar.gz",
 				},
@@ -279,7 +275,7 @@ func TestFullPipe(t *testing.T) {
 				Goarch:  "amd64",
 				Goamd64: "v1",
 				Type:    artifact.UploadableArchive,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID:       "foo",
 					artifact.ExtraFormat:   "tar.gz",
 					artifact.ExtraBinaries: []string{"name"},
@@ -292,7 +288,7 @@ func TestFullPipe(t *testing.T) {
 				Goarch:  "amd64",
 				Goamd64: "v3",
 				Type:    artifact.UploadableArchive,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID:       "foo",
 					artifact.ExtraFormat:   "tar.gz",
 					artifact.ExtraBinaries: []string{"name"},
@@ -341,7 +337,6 @@ func TestFullPipe(t *testing.T) {
 			}
 
 			golden.RequireEqualYaml(t, content)
-			requireValidManifest(t)
 
 			distBts, err := os.ReadFile(distFile)
 			require.NoError(t, err)
@@ -387,7 +382,7 @@ func TestRunPipePullRequest(t *testing.T) {
 		Goos:   "darwin",
 		Goarch: "all",
 		Type:   artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"foo"},
@@ -441,7 +436,7 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 		Goos:   "darwin",
 		Goarch: "all",
 		Type:   artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "unibin",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"unibin"},
@@ -459,7 +454,6 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 	require.NoError(t, publishAll(ctx, client))
 	require.True(t, client.CreatedFile)
 	golden.RequireEqualYaml(t, []byte(client.Content))
-	requireValidManifest(t)
 	distBts, err := os.ReadFile(distFile)
 	require.NoError(t, err)
 	require.Equal(t, client.Content, string(distBts))
@@ -497,7 +491,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "unibin",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"unibin"},
@@ -510,7 +504,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 		Goarch:  "arm64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "unibin",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"unibin"},
@@ -522,7 +516,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 		Goos:   "darwin",
 		Goarch: "all",
 		Type:   artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "unibin",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"unibin"},
@@ -541,7 +535,6 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 	require.NoError(t, publishAll(ctx, client))
 	require.True(t, client.CreatedFile)
 	golden.RequireEqualYaml(t, []byte(client.Content))
-	requireValidManifest(t)
 	distBts, err := os.ReadFile(distFile)
 	require.NoError(t, err)
 	require.Equal(t, client.Content, string(distBts))
@@ -580,7 +573,7 @@ func TestRunPipeNameTemplate(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"foo"},
@@ -598,7 +591,6 @@ func TestRunPipeNameTemplate(t *testing.T) {
 	require.NoError(t, publishAll(ctx, client))
 	require.True(t, client.CreatedFile)
 	golden.RequireEqualYaml(t, []byte(client.Content))
-	requireValidManifest(t)
 	distBts, err := os.ReadFile(distFile)
 	require.NoError(t, err)
 	require.Equal(t, client.Content, string(distBts))
@@ -663,7 +655,7 @@ func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"foo"},
@@ -777,7 +769,7 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 					Goarm:   a.goarm,
 					Goamd64: "v1",
 					Type:    artifact.UploadableArchive,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraID:       a.name,
 						artifact.ExtraFormat:   "tar.gz",
 						artifact.ExtraBinaries: []string{"foo"},
@@ -796,7 +788,6 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 			require.NoError(t, publishAll(ctx, client))
 			require.True(t, client.CreatedFile)
 			golden.RequireEqualYaml(t, []byte(client.Content))
-			requireValidManifest(t)
 
 			distBts, err := os.ReadFile(distFile)
 			require.NoError(t, err)
@@ -853,7 +844,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"foo"},
@@ -909,7 +900,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"bin"},
@@ -949,7 +940,7 @@ func TestRunMultipleBinaries(t *testing.T) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:       "foo",
 			artifact.ExtraFormat:   "tar.gz",
 			artifact.ExtraBinaries: []string{"bin1", "bin2"},
@@ -1016,17 +1007,3 @@ func manifestName(tb testing.TB) string {
 	tb.Helper()
 	return path.Base(tb.Name())
 }
-
-func requireValidManifest(t *testing.T) {
-	t.Helper()
-	t.Run("valid", func(t *testing.T) {
-		// needs to be the one on https://github.com/kubernetes-sigs/krew/pull/736
-		testlib.CheckPath(t, "validate-krew-manifest")
-		out, err := exec.Command(
-			"validate-krew-manifest",
-			"-skip-install",
-			"-manifest=testdata/"+strings.TrimSuffix(t.Name(), "/valid")+".yaml",
-		).CombinedOutput()
-		require.NoError(t, err, string(out))
-	})
-}
