@@ -1,4 +1,3 @@
-// Package winget creates winget manifests.
 package winget
 
 import (
@@ -117,11 +116,13 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 		&winget.Author,
 		&winget.PublisherURL,
 		&winget.PublisherSupportURL,
+		&winget.PrivacyURL,
 		&winget.Homepage,
 		&winget.SkipUpload,
 		&winget.Description,
 		&winget.ShortDescription,
 		&winget.ReleaseNotesURL,
+		&winget.InstallationNotes,
 		&winget.Path,
 		&winget.Copyright,
 		&winget.CopyrightURL,
@@ -235,6 +236,7 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 		Publisher:           winget.Publisher,
 		PublisherURL:        winget.PublisherURL,
 		PublisherSupportURL: winget.PublisherSupportURL,
+		PrivacyURL:          winget.PrivacyURL,
 		Author:              winget.Author,
 		PackageName:         winget.Name,
 		PackageURL:          winget.Homepage,
@@ -248,6 +250,7 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 		Tags:                fixTags(winget.Tags),
 		ReleaseNotes:        winget.ReleaseNotes,
 		ReleaseNotesURL:     winget.ReleaseNotesURL,
+		InstallationNotes:   winget.InstallationNotes,
 		ManifestType:        "defaultLocale",
 		ManifestVersion:     manifestVersion,
 	}, artifact.WingetDefaultLocale)
@@ -255,10 +258,10 @@ func (p Pipe) doRun(ctx *context.Context, winget config.Winget, cl client.Releas
 
 func (p Pipe) publishAll(ctx *context.Context, cli client.Client) error {
 	skips := pipe.SkipMemento{}
-	for _, files := range ctx.Artifacts.Filter(artifact.Or(
-		artifact.ByType(artifact.WingetInstaller),
-		artifact.ByType(artifact.WingetVersion),
-		artifact.ByType(artifact.WingetDefaultLocale),
+	for _, files := range ctx.Artifacts.Filter(artifact.ByTypes(
+		artifact.WingetInstaller,
+		artifact.WingetVersion,
+		artifact.WingetDefaultLocale,
 	)).GroupByID() {
 		err := doPublish(ctx, cli, files)
 		if err != nil && pipe.IsSkip(err) {
