@@ -13,16 +13,20 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/bluesky"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/brew"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/build"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/cask"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/changelog"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/checksums"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/chocolatey"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/discord"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/dist"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/docker"
+	dockerv2 "github.com/goreleaser/goreleaser/v2/internal/pipe/docker/v2"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/dockerdigest"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/gomod"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/ko"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/krew"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/linkedin"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/makeself"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/mastodon"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/mattermost"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/milestone"
@@ -78,6 +82,7 @@ var Defaulters = []Defaulter{
 	notary.MacOS{},
 	sourcearchive.Pipe{},
 	archive.Pipe{},
+	makeself.Pipe{},
 	nfpm.Pipe{},
 	snapcraft.Pipe{},
 	checksums.Pipe{},
@@ -85,7 +90,9 @@ var Defaulters = []Defaulter{
 	sign.DockerPipe{},
 	sbom.Pipe{},
 	docker.Pipe{},
+	dockerv2.Base{},
 	docker.ManifestPipe{},
+	dockerdigest.Pipe{},
 	artifactory.Pipe{},
 	blob.Pipe{},
 	upload.Pipe{},
@@ -94,6 +101,7 @@ var Defaulters = []Defaulter{
 	nix.Pipe{},
 	winget.Pipe{},
 	brew.Pipe{},
+	cask.Pipe{},
 	krew.Pipe{},
 	ko.Pipe{},
 	scoop.Pipe{},
