@@ -7,10 +7,12 @@ import (
 
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/chocolatey"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/docker"
+	dockerv2 "github.com/goreleaser/goreleaser/v2/internal/pipe/docker/v2"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/nix"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/sbom"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/sign"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe/snapcraft"
+	"github.com/goreleaser/goreleaser/v2/pkg/build"
 	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
@@ -27,6 +29,7 @@ type Healthchecker interface {
 //nolint:gochecknoglobals
 var Healthcheckers = []Healthchecker{
 	system{},
+	builds{},
 	snapcraft.Pipe{},
 	sign.Pipe{},
 	sign.BinaryPipe{},
@@ -34,11 +37,17 @@ var Healthcheckers = []Healthchecker{
 	sbom.Pipe{},
 	docker.Pipe{},
 	docker.ManifestPipe{},
+	dockerv2.Base{},
 	chocolatey.Pipe{},
-	nix.NewPublish(),
+	nix.New(),
 }
 
 type system struct{}
 
-func (system) String() string                           { return "system" }
-func (system) Dependencies(_ *context.Context) []string { return []string{"git", "go"} }
+func (system) String() string                         { return "system" }
+func (system) Dependencies(*context.Context) []string { return []string{"git"} }
+
+type builds struct{}
+
+func (builds) String() string                             { return "build" }
+func (builds) Dependencies(ctx *context.Context) []string { return build.Dependencies(ctx) }
